@@ -8,19 +8,13 @@ test_that("optimization with weights matches expectations", {
                 g=get_fitted_g(z.ash))
   expect_equal(get_fitted_g(z.ash.w)$pi, get_fitted_g(z.ash)$pi, tol=0.001)
 
-  testthat::skip_if_not_installed("mixsqp")
+  skip_if_not_installed("mixsqp")
   z.ash.w2 = ash(z,1,optmethod="mixSQP",weights = c(rep(1,50),rep(0,50)),
                  g = get_fitted_g(z.ash))
-  expect_equal(get_fitted_g(z.ash.w2)$pi, get_fitted_g(z.ash)$pi, tol=1e-5)
+  expect_equal(get_fitted_g(z.ash.w2)$pi, get_fitted_g(z.ash.w)$pi,tol = 1e-4)
 
-  # Since the Rmosek package on CRAN will not work with REBayes, here
-  # I check whether the correct Rmosek package (the one downloaded
-  # from mosek.com) is installed.
-  testthat::skip_if_not_installed("REBayes")
-  testthat::skip_if_not_installed("Rmosek")
-  testthat::skip_if(is.element("mosek_attachbuilder",
-                               getNamespaceExports("Rmosek")))
+  skip_if_mixkwdual_doesnt_work()
   z.ash.w3 = ash(z,1,optmethod="mixIP",weights = c(rep(1,50),rep(0,50)),
                  g = get_fitted_g(z.ash))
-  expect_equal(get_fitted_g(z.ash.w3)$pi, get_fitted_g(z.ash)$pi, tol=1e-5)
+  expect_equal(get_fitted_g(z.ash.w3)$pi, get_fitted_g(z.ash.w)$pi,tol = 1e-4)
 })
